
/*
 * The Real SoundTracker - GTK+ sample display widget (header)
 *
 * Copyright (C) 1998-1999 Michael Krause
 *
 * This program is free software; you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation; either version 2 of the License, or
 * (at your option) any later version.
 *
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License
 * along with this program; if not, write to the Free Software
 * Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA 02111-1307, USA.
 */

#ifndef _TRIGGER_TRACK_H
#define _TRIGGER_TRACK_H

#include <gdk/gdk.h>
#include <gtk/gtkwidget.h>

#include "aube.h"

#define TRIGGER_TRACK(obj)          GTK_CHECK_CAST (obj, trigger_track_get_type (), TriggerTrack)
#define TRIGGER_TRACK_CLASS(klass)  GTK_CHECK_CLASS_CAST (klass, trigger_track_get_type (), TriggerTrackClass)
#define IS_TRIGGER_TRACK(obj)       GTK_CHECK_TYPE (obj, trigger_track_get_type ())

typedef struct _TriggerTrack       TriggerTrack;
typedef struct _TriggerTrackClass  TriggerTrackClass;

enum {
    TRIGGER_TRACKCOL_BG,
    TRIGGER_TRACKCOL_FG,
    TRIGGER_TRACKCOL_LOOP,
    TRIGGER_TRACKCOL_MIXERPOS,
    TRIGGER_TRACKCOL_ZERO,
    TRIGGER_TRACKCOL_LAST
};

struct _TriggerTrack
{
    GtkWidget widget;
    int edit;                                     /* enable loop / selection editing */

    int width, height;
    GdkGC *bg_gc, *fg_gc, *loop_gc, *mixerpos_gc;

    seq_channel *data;
    int length;

    int datalen;
    int datatype;
    gboolean datacopy;                            /* do we have our own copy */
    int datacopylen;

    int win_start, win_length;
    int complete_redraw;

    int mixerpos, old_mixerpos;                   /* current playing offset of the sample */

    gboolean display_zero_line;
    GdkGC *zeroline_gc;

    /* selection handling */
    int sel_start, sel_end;                       /* offsets into the sample data or -1 */
    int old_ss, old_se;
    int button;                                   /* button index which started the selection */
    int selecting;
    int selecting_x0;                             /* the coordinate where the mouse was clicked */
    int selecting_wins0;

    /* loop points */
    int loop_start, loop_end;                     /* offsets into the sample data or -1 */
};

struct _TriggerTrackClass
{
    GtkWidgetClass parent_class;

    GdkColor colors[TRIGGER_TRACKCOL_LAST];

    void (*selection_changed)(TriggerTrack *s, int start, int end);
    void (*loop_changed)(TriggerTrack *s, int start, int end);
    void (*window_changed)(TriggerTrack *s, int start, int end);
};

guint          trigger_track_get_type            (void);
GtkWidget*     trigger_track_new                 (seq_channel * data, int length);

void           trigger_track_set_data_16         (TriggerTrack *s, gint16 *data, int len, gboolean copy);
void           trigger_track_set_data_8          (TriggerTrack *s, gint8 *data, int len, gboolean copy);
void           trigger_track_set_loop            (TriggerTrack *s, int start, int end);
void           trigger_track_set_selection       (TriggerTrack *s, int start, int end);
void           trigger_track_set_mixer_position  (TriggerTrack *s, int offset);
void           trigger_track_enable_zero_line    (TriggerTrack *s, gboolean enable);

void           trigger_track_set_window          (TriggerTrack *s, int start, int end);

#endif /* _TRIGGER_TRACK_H */
